@@ -1,13 +1,16 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
-my $tn  = translate('editnavi');
-my $ts  = translate('settings');
-my $td  = translate('database');
-my $tl  = translate('bookmarks');
-my $tf  = translate('explorer');
-my $te  = translate('env');
-my $tna = translate('navigation');
-my $tr  = translate('trash');
-my $trn = translate('translate');
+use vars qw($tn $ts $td $tl $te $tna $tr $trn);
+$tn  = translate('editnavi');
+$ts  = translate('settings');
+$td  = translate('database');
+$tl  = translate('bookmarks');
+$tf  = translate('explorer');
+$te  = translate('env');
+$tna = translate('navigation');
+$tr  = translate('trash');
+$trn = translate('translate');
 print
   qq|<table align="center" border="0" cellpadding="5" cellspacing="5" class="ShowTables marginTop" summary="adminlayout" >
 <tr>
@@ -25,3 +28,4 @@ print
 <td align="center"><img src="style/$m_sStyle/buttons/trash.png" alt="$tr" border="0" title="$tr"/><br/><a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=trash','trash','trash')">$tr</a></td>
 <td align="center"><img src="style/$m_sStyle/buttons/translate.png" alt="$trn" border="0" title="$trn"/><br/><a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=translate','translate','translate')">$trn</a></td>
 </tr></table><br/>|;
+1;
