@@ -1,8 +1,11 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
-my $remote_addr  = CGI::remote_addr()  ? CGI::remote_addr()  : 'none';
-my $query_string = CGI::query_string() ? CGI::query_string() : 'none';
-my $referer      = CGI::referer()      ? CGI::referer()      : 'none';
-my @count = $m_oDatabase->fetch_array(
+use vars qw($remote_addr, $query_string,$referer,@count);
+$remote_addr  = CGI::remote_addr()  ? CGI::remote_addr()  : 'none';
+$query_string = CGI::query_string() ? CGI::query_string() : 'none';
+$referer      = CGI::referer()      ? CGI::referer()      : 'none';
+@count = $m_oDatabase->fetch_array(
                         'select count(*) from exploit where `remote_addr` = ? && query_string = ? ',
                         $remote_addr, $query_string);
 if ($count[0] eq 0) {
