@@ -1,6 +1,10 @@
-my @menu =
+use utf8;
+use warnings;
+no warnings 'redefine';
+use vars qw(@menu @ret $blogs @t);
+@menu =
   $m_oDatabase->fetch_AoH('select id,name from blogs  where `right` <= ? order by id', $m_nRight);
-my @ret;
+
 for (my $i = 0 ; $i <= $#menu ; $i++) {
     use HTML::Entities;
     my $url = "requestURI('$ENV{SCRIPT_NAME}?action=viewrss&url=$menu[$i]->{id}','feeds','feeds')";
@@ -10,8 +14,8 @@ for (my $i = 0 ; $i <= $#menu ; $i++) {
         onclick => $url,
       };
 }
-my $blogs = "requestURI('$ENV{SCRIPT_NAME}?action=viewrss','feeds','feeds')";
-my @t = (
+$blogs = "requestURI('$ENV{SCRIPT_NAME}?action=viewrss','feeds','feeds')";
+@t = (
          {
           text    => 'Rss feeds',
           onclick => $blogs,
@@ -24,3 +28,4 @@ print '<br/></td></tr>';
 @menu     = undef;
 @t        = undef;
 $treeview = undef;
+1;
