@@ -296,8 +296,12 @@ $VAR1 = {
 	'lostpass'       => 'Dein Passwort',
 	'lostpassmessage'=> 'Du erhälst diese Mail weil Du dein Passwort angefordert hast.',
 	'forgetPass'     => 'Passwort vergessen.',
+        'SaveNewTable'     => 'Tabelle', 
+        'helptopics'     => 'Hilfe', 
     },
     'en' => {
+        'helptopics'     => 'Help', 
+        'SaveNewTable'     => 'Table', 
         'createdatabase'     => 'New Database',
         'wrong_captcha_text' => 'Wrong Captcha',
         'maxlength'          => 'Maxlength',
